# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Data-UUID
Version:	1.227
Release:	1.%{__distinit}%{__distvers}
Summary:	Globally/Universally Unique Identifiers (GUIDs/UUIDs)
# Makefile.PL says BSD but LICENSE file is HP-1989
# LICENSE: HP-1989
# source/ptable.h: GPL-1.0-or-later OR Artistic-1.0-Perl
# Issue for license clarification
# https://github.com/bleargh45/Data-UUID/issues/26
License:	HP-1989 AND (GPL-1.0-or-later OR Artistic-1.0-Perl)
URL:		https://metacpan.org/release/Data-UUID
Source0:	https://cpan.metacpan.org/modules/by-module/Data/Data-UUID-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(Pod::Usage)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(blib)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Digest::MD5)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Test::More)
BuildRequires:	perl(threads)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.06
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Avoid provides for private shared objects
%{?perl_default_filter}

%description
This module provides a framework for generating v3 UUIDs (Universally Unique
Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is 128
bits long, and is guaranteed to be different from all other UUIDs/GUIDs
generated until 3400 CE.

UUIDs were originally used in the Network Computing System (NCS) and later in
the Open Software Foundation's (OSF) Distributed Computing Environment.
Currently many different technologies rely on UUIDs to provide unique identity
for various software components. Microsoft COM/DCOM for instance, uses GUIDs
very extensively to uniquely identify classes, applications and components
across network-connected systems.

The algorithm for UUID generation, used by this extension, is described in the
Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz (see RFC 4122).
It provides a reasonably efficient and reliable framework for generating UUIDs
and supports fairly high allocation rates - 10 million per second per machine -
and therefore is suitable for identifying both extremely short-lived and very
persistent objects on a given system as well as across the network.

This module provides several methods to create a UUID. In all methods,
<namespace> is a UUID and <name> is a free form string.

%prep
%setup -q -n Data-UUID-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTHOR_TESTING=1
perl smp-test/collision.t

%files
%license LICENSE
%doc Changes README
%{perl_vendorarch}/auto/Data/
%{perl_vendorarch}/Data/
%{_mandir}/man3/Data::UUID.3*

%changelog
* Tue Mar 19 2024 Paul Howarth <paul@city-fan.org> - 1.227-1
- Update to 1.227
  - New maintainer, GTERMARS
  - Add basic GitHub Actions setup for testing
  - Typo corrections in POD
  - Eliminated use of state/node files in temp directory (CVE-2013-4184)

* Sun Sep  3 2023 Paul Howarth <paul@city-fan.org> - 1.226-14
- Update license to SPDX format

* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 1.226-12
- Perl 5.38 rebuild

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1.226-9
- Perl 5.36 rebuild

* Thu Dec 16 2021 Paul Howarth <paul@city-fan.org> - 1.226-7
- BR: perl(blib) for smp-test/collision.t

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1.226-5
- Perl 5.34 rebuild

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1.226-2
- Perl 5.32 rebuild

* Sun Apr 12 2020 Paul Howarth <paul@city-fan.org> - 1.226-1
- Update to 1.226
  - Set umask before fopen in destructor (GH#35)

* Sun Jun  2 2019 Paul Howarth <paul@city-fan.org> - 1.224-2
- Perl 5.30 rebuild

* Sun Mar  3 2019 Paul Howarth <paul@city-fan.org> - 1.224-1
- Update to 1.224
  - Properly quote C strings passed in DEFINE
  - Fix memory leak by decreasing reference count
  - Use File::Spec to get tmpdir instead of hardcoding

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.221-11
- Perl 5.28 rebuild

* Tue Aug  8 2017 Paul Howarth <paul@city-fan.org> - 1.221-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1.221-7
- Perl 5.26 rebuild

* Fri Apr 28 2017 Paul Howarth <paul@city-fan.org> - 1.221-6
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Wed May 18 2016 Paul Howarth <paul@city-fan.org> - 1.221-4
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Tue Aug 11 2015 Paul Howarth <paul@city-fan.org> - 1.221-1
- Update to 1.221
  - Documentation improvements

* Thu Dec 18 2014 Paul Howarth <paul@city-fan.org> - 1.220-1
- Update to 1.220
  - Improve chances it'll work on Android
- Classify buildreqs by usage

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 1.219-6
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Sat Aug 17 2013 Paul Howarth <paul@city-fan.org> - 1.219-2
- License is BSD, not MIT

* Thu Aug 15 2013 Paul Howarth <paul@city-fan.org> - 1.219-1
- Initial RPM version
